@@ -259,7 +259,7 @@ class Dongle():
   CMD_GETACCEL = 0x6B
   CMD_GETFORMFACTOR = 0x6C
   CMD_GETRGB = 0x6D
-  CMD_PLACEHOLDER201303291416 = 0x6E
+  CMD_GETVERSIONS = 0x6E
   CMD_PLACEHOLDER201304121823 = 0x6F
   CMD_PLACEHOLDER201304152311 = 0x70
   CMD_PLACEHOLDER201304161605 = 0x71
@@ -276,7 +276,7 @@ class Dongle():
   CMD_TWI_SEND = 0x7C
   CMD_TWI_RECV = 0x7D
   CMD_TWI_SENDRECV = 0x7E
-  CMD_PLACEHOLDER201306271044 = 0x7F
+  CMD_SET_ACCEL = 0x7F
   CMD_SMOOTHMOVE = 0x80
   CMD_SETMOTORSTATES = 0x81
   CMD_SETGLOBALACCEL = 0x82
@@ -309,7 +309,7 @@ class Dongle():
     self.ctxReadQueue = Queue.Queue()
     self.link = None
     self.phys = None
-    self.children = [] # List of Linkbots
+    self.children = {} # List of Linkbots
     self.scannedIDs = {}
     self.scannedIDs_cond = threading.Condition()
     self.giant_lock = threading.Lock()
@@ -324,7 +324,7 @@ class Dongle():
     self.commsOutThread.start()
 
   def addLinkbot(self, linkbot):
-    self.children.append(linkbot)
+    self.children[linkbot.getSerialID()] = linkbot
 
   def autoConnect(self):
     if os.name == 'nt':
@@ -415,7 +415,7 @@ class Dongle():
   def disconnect(self):
     self.link.stop()
     self.phys.disconnect()
-    self.children = []
+    self.children = {}
 
   def handlePacket(self, packet):
     self.readQueue.put(packet)
@@ -438,11 +438,13 @@ class Dongle():
       self.waitForRobot(serialID)
     if linkbotClass is None:
       linkbotClass = Linkbot
+    if serialID in self.children:
+      return self.children[serialID]
     l = linkbotClass()
     l.zigbeeAddr = self.scannedIDs[serialID]
     l.serialID = serialID
     l.baroboCtx = self
-    self.children.append(l)
+    self.children[serialID] = l
     l.form = l.getFormFactor()
     if l.zigbeeAddr != self.zigbeeAddr:
       l._pairParent()
@@ -493,7 +495,7 @@ class Dongle():
       if 0 == zigbeeAddr:
         self.ctxReadQueue.put(packet)
         continue
-      for linkbot in self.children:
+      for _, linkbot in self.children.items():
         if zigbeeAddr == linkbot.zigbeeAddr:
           linkbot.readQueue.put(packet, block=True)
           break
@@ -534,7 +536,7 @@ class Dongle():
           continue
         else:
           raise
-    serialID = _unpack('!4s', response[2:6])[0]
+    serialID = _unpack('!4s', response[2:6])[0].decode('UTF-8')
     buf = [self.CMD_GETADDRESS, 3, 0x00]
     self.writePacket(_comms.Packet(buf, 0x0000))
     response = self.ctxReadQueue.get(block=True, timeout=2.0)
